@@ -7,12 +7,10 @@ DifferentialEquations
 
 """
 
-__all__ = ['euler_method', 'euler_caushy', 'runge_kutta']
-
-from .Euler import euler_method
-from .Euler_Caushy import euler_caushy
-from .Runge_Kutta import runge_kutta
+from .DiffEq import euler_method
+from .DiffEq import euler_caushy
+from .DiffEq import runge_kutta
 
 __author__ = "Alexandr Savostianov"
 
-__version__ = "0.0.0"
\ No newline at end of file
+__version__ = "0.0.1"
\ No newline at end of file
